% DemoMullersMethodSimple
%
% Overview:
%   We use Muller's method to determine the roots of a complex valued
%   function.
%
% References:
%   Mathematical and Computational Methods in Photonics - Tutorial Notes
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Matias Ruiz, Sanghyeon Yu.
clc
clear all
close all

% --------------------------------------------------
% Define the complex function f(z) = sin(z) + 5 +  1i which has
% roots z = 2*pi*n - sin^-1(5+i) or 2*pi*n + pi + sin^-1(5+i)
% for n an integer.
% --------------------------------------------------
f = @(z) sin(z) + 5 +  1i;
z0_exact = - asin(5 + 1i);

% --------------------------------------------------
% Determine the comlex root using Muller's method.
% --------------------------------------------------
z0 = -1.2;
z1 = -1.4;
z2 = -1.5;
distTol = 5e-5;
fTol = 1e-12;
iterMax = 100;
[z0_muller, fRoot, iterN] = MullersMethod(f, z0, z1, z2, iterMax, distTol, fTol);

fprintf('Exact root:               %.8f %.8fi\n', real(z0_exact), imag(z0_exact));
fprintf('Muller method root:       %.8f %.8fi\n', real(z0_muller), imag(z0_muller));
fprintf('Number of iterations:     %d\n', iterN);

% --------------------------------------------------
% Plot the real and imaginary parts of f and mark the complex root.
% --------------------------------------------------
PlotRoot(f, z0_muller);