function PlotRoot(f, root)
% PlotRoot
%
% Overview:
%   Calculates the root of a complex valued function.
%
% Input:
%   f:          A complex-valued function.
%   root:       A root of f which will be marked on the plot.
%
% References:
%   Mathematical and Computational Methods in Photonics - Tutorial Notes
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Matias Ruiz, Sanghyeon Yu.

% --------------------------------------------------
% Calculate f on a grid for plotting.
% --------------------------------------------------
rx = real(root);
ry = imag(root);

gMax = 3;
dg = 0.1;
gRange = -gMax:dg:gMax;
[x,y] = meshgrid(gRange);

F = f(x + y*1i);

% --------------------------------------------------
% Plot the real part of f.
% --------------------------------------------------
xyCrossSize = 1;
zCrossSize = 3;
axisSize = 20;

h = figure(1);
set(h, 'Position', [100 100 1600 900]);

subplot(1, 2, 1)
h = surf(x,y,real(F),'EdgeColor','none');
grid off
xlabel('Re z')
ylabel('Im z')
zlabel('Re f(z)')
line([-axisSize, axisSize], [0, 0], [0, 0], 'Color', 'k', 'LineWidth', 1);
line([0, 0], [-axisSize, axisSize], [0, 0], 'Color', 'k', 'LineWidth', 1);
line([0, 0], [0, 0], [-axisSize, axisSize], 'Color', 'k', 'LineWidth', 1);
axis([-4, 4, -4, 4, -10, 20])
view([90, -65, 20])

line([rx-xyCrossSize, rx+xyCrossSize], [ry, ry], [0, 0], 'Color', 'm', 'LineWidth', 1);
line([rx, rx], [ry-xyCrossSize, ry+xyCrossSize], [0, 0], 'Color', 'm', 'LineWidth', 1);
line([rx, rx], [ry, ry], [-zCrossSize, zCrossSize], 'Color', 'm', 'LineWidth', 1);


% --------------------------------------------------
% Plot the imaginay part of f.
% --------------------------------------------------
subplot(1, 2, 2)
h = surf(x,y,imag(F),'EdgeColor','none');
grid off
xlabel('Re z')
ylabel('Im z')
zlabel('Im f(z)')
set(h, 'edgecolor', 'none');
line([-2, 2], [0, 0], [0, 0], 'Color', 'k', 'LineWidth', 1);
line([0, 0], [-2, 2], [0, 0], 'Color', 'k', 'LineWidth', 1);
line([0, 0], [0, 0], [-axisSize, axisSize], 'Color', 'k', 'LineWidth', 1);


line([rx-xyCrossSize, rx+xyCrossSize], [ry, ry], [0, 0], 'Color', 'm', 'LineWidth', 1);
line([rx, rx], [ry-xyCrossSize, ry+xyCrossSize], [0, 0], 'Color', 'm', 'LineWidth', 1);
line([rx, rx], [ry, ry], [-zCrossSize, zCrossSize], 'Color', 'm', 'LineWidth', 1);
axis([-4, 4, -4, 4, -15, 15])
view([90, -65, 20])